@@ -2,8 +2,11 @@
 
 var glob = require('glob');
 var fs = require('fs');
+var path = require('path');
 var buffered = require('./util/buffered');
 
+
+// Preare fixtures
 var fixturesDir = __dirname + '/fixtures';
 
 glob.sync('prepare_*', { cwd: __dirname + '/fixtures' }).forEach(function (file) {
@@ -16,6 +19,7 @@ glob.sync('prepare_*', { cwd: __dirname + '/fixtures' }).forEach(function (file)
     process.stdout.write('Copied "' + file + '" to "' + finalFile + '"\n');
 });
 
+// Install spawn-sync for older node versions
 if (/^v0\.10\./.test(process.version)) {
     process.stdout.write('Installing spawn-sync..\n');
     buffered('spawn', 'npm', ['install', 'spawn-sync'], { stdio: 'inherit' }, function (err) {
@@ -26,3 +30,13 @@ if (/^v0\.10\./.test(process.version)) {
         process.exit();
     });
 }
+
+// Fix AppVeyor tests because Git bin folder is in PATH and it has a "echo" program there
+if (process.env.APPVEYOR) {
+    process.env.PATH = process.env.PATH
+    .split(path.delimiter)
+    .filter(function (entry) {
+        return !/\\git\\bin$/i.test(path.normalize(entry));
+    })
+    .join(path.delimiter);
+}
